<?php
/**
*
* @package Easy Download System
* @version $Id: index.php 213 2011-12-21 07:12:48Z femu $
* @copyright (c) 2009, 2010 wuerzi & femu
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
define('UMIL_AUTO', true);
define('IN_PHPBB', true);
define('IN_INSTALL', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './../';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup();

if (!file_exists($phpbb_root_path . 'umil/umil_auto.' . $phpEx))
{
	trigger_error('Please download the latest UMIL (Unified MOD Install Library) from: <a href="http://www.phpbb.com/mods/umil/">phpBB.com/mods/umil</a>', E_USER_ERROR);
}

// The name of the mod to be displayed during installation.
$mod_name = 'EDS_TITLE';

/*
* The name of the config variable which will hold the currently installed version
* You do not need to set this yourself, UMIL will handle setting and updating the version itself.
*/

$version_config_name = 'dm_eds_version';

/*
* The language file which will be included when installing
* Language entries that should exist in the language file for UMIL (replace $mod_name with the mod's name you set to $mod_name above)
*/
$language_file = 'mods/dm_eds';

/*
* Optionally we may specify our own logo image to show in the upper corner instead of the default logo.
* $phpbb_root_path will get prepended to the path specified
* Image height should be 50px to prevent cut-off or stretching.
*/
$logo_img = 'install/dm_logo.png';

/*
* The array of versions and actions within each.
* You do not need to order it a specific way (it will be sorted automatically), however, you must enter every version, even if no actions are done for it.
*
* You must use correct version numbering.  Unless you know exactly what you can use, only use X.X.X (replacing X with an integer).
* The version numbering must otherwise be compatible with the version_compare function - http://php.net/manual/en/function.version-compare.php
*/

/**
* Define the basic structure
* The format:
*		array('{TABLE_NAME}' => {TABLE_DATA})
*		{TABLE_DATA}:
*			COLUMNS = array({column_name} = array({column_type}, {default}, {auto_increment}))
*			PRIMARY_KEY = {column_name(s)}
*			KEYS = array({key_name} = array({key_type}, {column_name(s)})),
*
*	Column Types:
*	INT:x		=> SIGNED int(x)
*	BINT		=> BIGINT
*	UINT		=> mediumint(8) UNSIGNED
*	UINT:x		=> int(x) UNSIGNED
*	TINT:x		=> tinyint(x)
*	USINT		=> smallint(4) UNSIGNED (for _order columns)
*	BOOL		=> tinyint(1) UNSIGNED
*	VCHAR		=> varchar(255)
*	CHAR:x		=> char(x)
*	XSTEXT_UNI	=> text for storing 100 characters (topic_title for example)
*	STEXT_UNI	=> text for storing 255 characters (normal input field with a max of 255 single-byte chars) - same as VCHAR_UNI
*	TEXT_UNI	=> text for storing 3000 characters (short text, descriptions, comments, etc.)
*	MTEXT_UNI	=> mediumtext (post text, large text)
*	VCHAR:x		=> varchar(x)
*	TIMESTAMP	=> int(11) UNSIGNED
*	DECIMAL		=> decimal number (5,2)
*	DECIMAL:		=> decimal number (x,2)
*	PDECIMAL		=> precision decimal number (6,3)
*	PDECIMAL:	=> precision decimal number (x,3)
*	VCHAR_UNI	=> varchar(255) BINARY
*	VCHAR_CI		=> varchar_ci for postgresql, others VCHAR
*/

$versions = array(
	// Version 1.0.0 - this is the first version using UMIL
	'1.0.0'	=> array(
		// Now to add the tables (this uses the layout from develop/create_schema_files.php and from phpbb_db_tools)
		'table_add' => array(

			array($table_prefix . 'dm_eds', array(
					'COLUMNS'		=> array(
						'download_id'		=> array('UINT:8', NULL, 'auto_increment'),
						'download_count'	=> array('UINT:8', 0),
						'download_title'	=> array('VCHAR', ''),
						'download_filename'	=> array('VCHAR', ''),
						'download_desc'		=> array('MTEXT_UNI',  ''),
						'download_version'	=> array('VCHAR:10', 0),
						'download_cat_id'	=> array('UINT:8', 0),
						'bbcode_bitfield'	=> array('VCHAR', ''),
						'bbcode_uid'		=> array('VCHAR:8', ''),
						'bbcode_options'	=> array('UINT:8', 0),
						'upload_time'		=> array('UINT:8', 0),
						'last_changed_time'	=> array('UINT:8', 0),
						'cost_per_dl'		=> array('DECIMAL:10', 0.00),
					),
					'PRIMARY_KEY'	=> 'download_id',
				),
			),

			array($table_prefix . 'dm_eds_cat', array(
					'COLUMNS'		=> array(
						'cat_id'			=> array('UINT:8', NULL, 'auto_increment'),
						'parent_id'			=> array('UINT:8', 0),
						'left_id'			=> array('UINT:8', 0),
						'right_id'			=> array('UINT:8', 0),
						'cat_parents'		=> array('MTEXT_UNI',  ''),
						'cat_name'			=> array('VCHAR', 0),
						'cat_desc'			=> array('MTEXT_UNI', 0),
						'cat_sub_dir'		=> array('VCHAR', ''),
						'cat_desc_uid'		=> array('VCHAR:8', ''),
						'cat_desc_bitfield'	=> array('VCHAR:8', 0),
						'cat_desc_options'	=> array('UINT:8', 0),
					),
					'PRIMARY_KEY'	=> 'cat_id',
				),
			),

			array($table_prefix . 'dm_eds_config', array(
					'COLUMNS'		=> array(
						'pagination_acp'	=> array('TINT:3', 0),
						'pagination_user'	=> array('TINT:3', 0),
						'costs_per_dl'		=> array('DECIMAL:10', 0.00),
					),
				),
			),
		),

		// Clear the general cache as well as the templates, imagesets and themes cache
		'cache_purge' => array(
			array(),
			array('imageset'),
			array('template'),
			array('theme'),
		),

		// Alright, now lets add some modules to the ACP
		'module_add' => array(
			// First, lets add a new category named ACP_DM_EDS to ACP_CAT_DOT_MODS
			array('acp', 'ACP_CAT_DOT_MODS', 'ACP_DM_EDS'),

			// Now we will add the config module to the ACP_DM_EDS
			array('acp', 'ACP_DM_EDS', array(
					'module_basename'	=> 'dm_eds',
					'module_langname'	=> 'ACP_MANAGE_CONFIG',
					'module_mode'		=> 'config',
					'module_auth'		=> 'acl_a_board',
				),
			),

			// Now we will add the config module to the ACP_DM_EDS
			array('acp', 'ACP_DM_EDS', array(
					'module_basename'	=> 'dm_eds',
					'module_langname'	=> 'ACP_MANAGE_CATEGORIES',
					'module_mode'		=> 'categories',
					'module_auth'		=> 'acl_a_board',
				),
			),

			// Now we will add the managae downloads to the ACP_DM_EDS
			array('acp', 'ACP_DM_EDS', array(
					'module_basename'	=> 'dm_eds',
					'module_langname'	=> 'ACP_MANAGE_DOWNLOADS',
					'module_mode'		=> 'downloads',
					'module_auth'		=> 'acl_a_board',
				),
			),

			// Now we will add the userguide modul to the ACP_DM_EDS
			array('acp', 'ACP_DM_EDS', array(
					'module_basename'	=> 'dm_eds',
					'module_langname'	=> 'ACP_USERGUIDE',
					'module_mode'		=> 'userguide',
					'module_auth'		=> 'acl_a_board',
				),
			),
		),

		// Update filesize
		'custom'	=> 'eds_update_filesize',

		/*
		* Now we need to insert some data.  The easiest way to do that is through a custom function
		* Enter 'custom' for the array key and the name of the function for the value.
		*/
		'custom'	=> 'first_fill_1_0_0',
	),

	// Version 1.0.1
	'1.0.1'		=> array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',

		// Version 1.0.1 adds announce_enable and announce_forum
		'custom'	=> 'fill_1_0_1',
	),

	// Version 1.0.2
	'1.0.2' => array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',

		// Version 1.0.2 adds filesize and change bbcode_options format
		'custom'	=> 'fill_1_0_2',
	),

	// Version 1.0.3 only update Version
	'1.0.3'		=> array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',
	),

	// Version 1.0.4
	'1.0.4' => array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',

		// Version 1.0.4 adds points_user_id
		'custom'	=> 'fill_1_0_4',
	),

	// Version 1.0.5 only update Version
	'1.0.5'		=> array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',
	),

	// Version 1.0.6 adds permissions
	'1.0.6'		=> array(
		// Update filesize
		'custom'	=> 'eds_update_filesize',

		// Now to add permission for the DM EDS
		'permission_add' => array(
			array('u_dm_eds_use', true),
			array('u_dm_eds_download', true),
			array('a_dm_eds', true),
		),

		// How about we give some default permissions then as well?
		'permission_set' => array(
			array('GUESTS', 'u_dm_eds_use', 'group'),
			array('GUESTS', 'u_dm_eds_download', 'group'),
			array('REGISTERED', 'u_dm_eds_use', 'group'),
			array('REGISTERED', 'u_dm_eds_download', 'group'),
			array('ROLE_ADMIN_STANDARD', 'a_dm_eds', 'role'),
		),
		// Version 1.0.6 changes filsize field to int(11)
		'custom'	=> 'fill_1_0_6',
	),

	// Version 1.0.7 only update Version
	'1.0.7'		=> array(),

	// Version 1.0.8 only update Version
	'1.0.8'		=> array(),

	// Version 1.0.9 only update Version
	'1.0.9'		=> array(),

	// Version 1.0.10 only update Version
	'1.0.10'		=> array(),
);

// Include the UMIF Auto file and everything else will be handled automatically.
include($phpbb_root_path . 'umil/umil_auto.' . $phpEx);

/*
* Here is our custom function that will be called for version 1.0.0
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function first_fill_1_0_0($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
			// Run this when installing the first time
			if ($umil->table_exists($table_prefix . 'dm_eds_config'))
			{
				// before we fill anything in this table, we truncate it. Maybe someone missed an old installation.
				$db->sql_query('TRUNCATE TABLE ' . $table_prefix . 'dm_eds_config');

				$sql_ary = array();

				$sql_ary[] = array(
					'pagination_acp' => '5',
					'pagination_user' => '3',
				);

				$db->sql_multi_insert($table_prefix . 'dm_eds_config ', $sql_ary);
			}

			// Send the message, that the command was successful
			return 'EDS_INSERT_FIRST_FILL';
		break;

		case 'update' :
		break;

 		case 'uninstall' :
		break;
	}
}

/*
* Here is our custom function that will be called for version 1.0.1
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function fill_1_0_1($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
		case 'update' :
			// Run this when installing/updating
			if ($umil->table_exists($table_prefix . 'dm_eds_config'))
			{
				$sql = "ALTER TABLE " . $table_prefix . "dm_eds_config
					ADD announce_enable TINYINT(1) NOT NULL DEFAULT '0'";
				$db->sql_query($sql);

				$sql = "ALTER TABLE " . $table_prefix . "dm_eds_config
					ADD announce_forum INT(10) UNSIGNED NOT NULL DEFAULT '0'";
				$db->sql_query($sql);
			}

			// Method 1 of displaying the command (and Success for the result)
			return 'EDS_UPDATE_SUCCESSFUL';
		break;

		case 'uninstall' :
		break;
	}
}

/*
* Here is our custom function that will be called for version 1.0.2
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function fill_1_0_2($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
		case 'update' :
			// Run this when installing/updating
			if ($umil->table_exists($table_prefix . 'dm_eds'))
			{
				$sql = "ALTER TABLE " . $table_prefix . "dm_eds
					CHANGE bbcode_options bbcode_options VARCHAR(255) NOT NULL DEFAULT ''";
				$db->sql_query($sql);

				$sql = "ALTER TABLE " . $table_prefix . "dm_eds
					ADD filesize INT(8) UNSIGNED NOT NULL DEFAULT '0'";
				$db->sql_query($sql);
			}

			// Method 1 of displaying the command (and Success for the result)
			return 'EDS_UPDATE_SUCCESSFUL';
		break;

		case 'uninstall' :
		break;
	}
}

/*
* Here is our custom function that will be called for version 1.0.4
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function fill_1_0_4($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
		case 'update' :
			// Run this when installing/updating
			if ($umil->table_exists($table_prefix . 'dm_eds'))
			{
				$sql = "ALTER TABLE " . $table_prefix . "dm_eds
					ADD points_user_id INT(8) UNSIGNED NOT NULL DEFAULT '0'";
				$db->sql_query($sql);
			}

			// Method 1 of displaying the command (and Success for the result)
			return 'EDS_UPDATE_SUCCESSFUL';
		break;

		case 'uninstall' :
		break;
	}
}

/*
* Here is our custom function that will be called for version 1.0.6
*
* @param string $action The action (install|update|uninstall) will be sent through this.
* @param string $version The version this is being run for will be sent through this.
*/
function fill_1_0_6($action, $version)
{
	global $db, $table_prefix, $umil;

	switch ($action)
	{
		case 'install' :
		case 'update' :
			// Run this when installing/updating
			if ($umil->table_exists($table_prefix . 'dm_eds'))
			{
				$sql = "ALTER TABLE " . $table_prefix . "dm_eds
					CHANGE filesize filesize INT(11) UNSIGNED NOT NULL DEFAULT '0'";
				$db->sql_query($sql);
			}

			// Change the main permission for the modules
			if ($umil->table_exists($table_prefix . 'modules'))
			{
				$sql = "UPDATE " . $table_prefix . "modules
					SET module_auth = 'acl_a_dm_eds' 
					WHERE module_langname = 'ACP_DM_EDS'";
				$db->sql_query($sql);

				$sql = "UPDATE " . $table_prefix . "modules
					SET module_auth = 'acl_a_dm_eds' 
					WHERE module_basename = 'dm_eds'
						AND module_langname = 'ACP_MANAGE_CONFIG'";
				$db->sql_query($sql);

				$sql = "UPDATE " . $table_prefix . "modules
					SET module_auth = 'acl_a_dm_eds' 
					WHERE module_basename = 'dm_eds'
						AND module_langname = 'ACP_MANAGE_DOWNLOADS'";
				$db->sql_query($sql);

				$sql = "UPDATE " . $table_prefix . "modules
					SET module_auth = 'acl_a_dm_eds' 
					WHERE module_basename = 'dm_eds'
						AND module_langname = 'ACP_MANAGE_CATEGORIES'";
				$db->sql_query($sql);

				$sql = "UPDATE " . $table_prefix . "modules
					SET module_auth = 'acl_a_dm_eds' 
					WHERE module_basename = 'dm_eds'
						AND module_langname = 'ACP_USERGUIDE'";
				$db->sql_query($sql);
			}

			// Method 1 of displaying the command (and Success for the result)
			return 'EDS_UPDATE_SUCCESSFUL';
		break;

		case 'uninstall' :
		break;
	}
}

/**
* Following function is needed to update the file sizes 
*/
function eds_update_filesize()
{
	global $db, $phpbb_root_path;
	$dm_eds_file_path = (defined('DM_EDS_FILE_PATH')) ? DM_EDS_FILE_PATH : 'dm_eds/files/';
	$dm_eds_file_dir = $phpbb_root_path . $dm_eds_file_path;
	$dir = @opendir($dm_eds_file_dir);

	while ($file = @readdir($dir))
	{
		if (@is_dir($dm_eds_file_dir . '/' . $file) && $file != "." && $file != "..")
		{
			$dirname = $dm_eds_file_dir . '/' . $file;
			$subdir = @opendir($dirname);
			//Grab cat ID
			$sql = 'SELECT cat_id FROM ' . DM_EDS_CAT_TABLE . "
			WHERE cat_sub_dir LIKE '$file'";
			$result = $db->sql_query($sql);
			$row = $db->sql_fetchrow($result);
			$cat_id = $row['cat_id'];
			$db->sql_freeresult($result);

			while ($file1 = @readdir($subdir))
			{
				$filename = $dirname . '/' . $file1;
				if(!is_dir($filename) && $cat_id && $file1 != "." && $file1 != "..")
				{
					$filesize = @filesize($filename);
					//Update filesize
					$sql = 'UPDATE ' . DM_EDS_TABLE . "
						SET filesize = $filesize
						WHERE download_filename LIKE '$file1'
							AND download_cat_id = $cat_id";
					$db->sql_query($sql);
				}
			}
			@closedir($subdir);
		}
	}
	@closedir($dir);
	return;
}

?>